pub struct Ledger<TransactionType> {Show 13 fields
pub account_hash: String,
pub close_flags: u64,
pub close_time: LedgerTimestamp,
pub close_time_human: String,
pub close_time_resolution: u32,
pub closed: bool,
pub ledger_hash: String,
pub ledger_index: String,
pub parent_close_time: LedgerTimestamp,
pub parent_hash: String,
pub total_coins: String,
pub transaction_hash: String,
pub transactions: Option<Vec<TransactionType>>,
}Fields
account_hash: StringHash of all account state information in this ledger, as hex.
close_flags: u64close_time: LedgerTimestampThe time this ledger was closed, in seconds since the Ripple Epoch.
close_time_human: StringThe time this ledger was closed, in human-readable format. Always uses the UTC time zone.
close_time_resolution: u32Ledger close times are rounded to within this many seconds.
closed: boolWhether or not this ledger has been closed.
ledger_hash: StringUnique identifying hash of the entire ledger.
ledger_index: StringThe Ledger Index of this ledger, as a quoted integer.
parent_close_time: LedgerTimestampThe time at which the previous ledger was closed.
parent_hash: StringUnique identifying hash of the ledger that came immediately before this one.
total_coins: StringTotal number of XRP drops in the network, as a quoted integer. (This decreases as transaction costs destroy XRP.)
transaction_hash: StringHash of the transaction information included in this ledger, as hex
transactions: Option<Vec<TransactionType>>(Omitted unless requested) Transactions applied in this ledger version. By default, members are the transactions identifying Hash strings. If the request specified expand as true, members are full representations of the transactions instead, in either JSON or binary depending on whether the request specified binary as true.